@@ -62,7 +62,6 @@ const READ_REMOTE_CACHE_OPTION: &str = "read-remote-cache";
 const WRITE_REMOTE_CACHE_OPTION: &str = "write-remote-cache";
 const DOCKER_CLI_OPTION: &str = "docker-cli";
 const DOCKER_REPO_OPTION: &str = "docker-repo";
-const DEPRECATED_REPO_OPTION: &str = "repo";
 const LIST_OPTION: &str = "list";
 const SHELL_OPTION: &str = "shell";
 const TASKS_OPTION: &str = "tasks";
@@ -220,12 +219,6 @@ fn settings() -> Result<Settings, Failure> {
                 .long(DOCKER_REPO_OPTION)
                 .help("Sets the Docker repository"),
         )
-        .arg(
-            Arg::with_name(DEPRECATED_REPO_OPTION)
-                .value_name("REPO")
-                .long(DEPRECATED_REPO_OPTION)
-                .help("Deprecated, use --docker-repo instead"),
-        )
         .arg(
             Arg::with_name(DOCKER_CLI_OPTION)
                 .value_name("CLI")
@@ -340,7 +333,6 @@ fn settings() -> Result<Settings, Failure> {
     // Read the Docker repo.
     let docker_repo = matches
         .value_of(DOCKER_REPO_OPTION)
-        .or_else(|| matches.value_of(DEPRECATED_REPO_OPTION))
         .unwrap_or(&config.docker_repo)
         .to_owned();
 
